@@ -25,71 +25,75 @@
 #include <config.h>
 #endif
 
-#include <kapp.h>
 #include <qwidget.h>
-#include <kpassdlg.h>
 #include <qstring.h>
 #include <qtextcodec.h>
 #include <kprocess.h>
-class KCookie;
+#include <kpassworddialog.h>
+#include <knewpassworddialog.h>
 
+#include "kcookie.h"
 /*
 * KdeSudo is the base class of the project
 *
-* It inherits KPasswordDialog and overrrides the
-* slot slotOK()
-*
-* @author Robert Gruber <rgruber@users.sourceforge.net>
-* @version 2.4
+* @version 3.1
 */
 
-class KdeSudo : public KPasswordDialog
-{
+/* buffer is used when reading from the KProcess child */
+#define BUFSIZE 1024
+
+class KdeSudo : QObject {
 	Q_OBJECT 
 	public:
-	/*
-	* Default construtor
-	*/
-	KdeSudo(QWidget* parent=0, const char *name=0, const QString& icon=QString(), const QString& generic=QString(), bool withIgnoreButton=false);
+		KdeSudo( const QString& icon = QString(),
+		const QString& generic = QString()
+	);
 
-	/*
-	* Default destructor
-	*/
 	~KdeSudo();
+
 	enum ResultCodes { AsUser = 10 };
 
-public slots: // Public slots
-	/*
-	* This slot gets exectuted if sudo creates some output
-	*/
-	void receivedOut(KProcess*proc, char*buffer, int buflen);
-	/*
-	* This slot gets exectuted when sudo exits
-	*/
-	void procExited(KProcess *proc);
-	/*
-	* This slot overrides the slot from KPasswordDialog
-	* @see KPasswordDialog
-	*/
-	void slotOk();
-	void slotUser1();
-	QString validArg(QString arg);
+	public slots:
 
-private: // Private attributes
-	KProcess * p;
-	bool bError;
-	bool newDcop;
-	bool keepPwd;
-	bool emptyPwd;
-	bool useTerm;
-	bool noExec;
-	bool unCleaned;
-	QString m_tmpname;
-	QString iceauthorityFile;
-	QString dcopServer;
-	KCookie* m_pCookie;
-	void blockSigChild();
-	void unblockSigChild();
+		/*
+		* This slot gets executed if sudo creates some output
+		* -- well, in theory it should. Even though the code
+		*  seems to be doing what the API says, it doesn't
+		*  yet do what we need.
+		*/
+		void parseOutput();
+	
+		/*
+		* This slot gets exectuted when sudo exits
+		*/
+		void procExited();
+	
+		/*
+		* This slot overrides the slot from KPasswordDialog
+		* @see KPasswordDialog
+		*/
+		void pushPassword(const QString&);
+                void slotCancel();
+		void slotUser1();
+		QString validArg(QString arg);
+
+	private:
+		void error(const QString&);
+		KProcess *p;
+		bool bError;
+		// bool newDcop; // deprecated
+		bool keepPwd;
+		bool emptyPwd;
+		bool useTerm;
+		bool noExec;
+		bool unCleaned;
+		QString m_tmpName;
+		QString iceauthorityFile;
+		KDESu::KDESuPrivate::KCookie* m_pCookie;
+		void blockSigChild();
+		void unblockSigChild();
+
+		KPasswordDialog* m_dialog;
 };
 
-#endif
+#endif // KDESUDO_H
